class Thief(object):
    """Thief fake class"""

    def __init__(self, first_name, last_name):
        """
        Args:
            first_name (str): thief first name
            last_name (str): thief last name
        """
        self.first_name = first_name
        self.last_name = last_name
